pub enum IMonadStakingEvents {
ValidatorRewarded(ValidatorRewarded),
ValidatorCreated(ValidatorCreated),
ValidatorStatusChanged(ValidatorStatusChanged),
Delegate(Delegate),
Undelegate(Undelegate),
Withdraw(Withdraw),
ClaimRewards(ClaimRewards),
CommissionChanged(CommissionChanged),
EpochChanged(EpochChanged),
}monad only.Expand description
Container for all the IMonadStaking events.
Variants
ValidatorRewarded(ValidatorRewarded)
ValidatorCreated(ValidatorCreated)
ValidatorStatusChanged(ValidatorStatusChanged)
Delegate(Delegate)
Undelegate(Undelegate)
Withdraw(Withdraw)
ClaimRewards(ClaimRewards)
CommissionChanged(CommissionChanged)
EpochChanged(EpochChanged)
Implementations
Sourceimpl IMonadStakingEvents
impl IMonadStakingEvents
Sourcepub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl IMonadStakingEvents
impl IMonadStakingEvents
Sourcepub fn validator_rewarded(
validator_id: u64,
from: Address,
amount: U256,
epoch: u64,
) -> Self
pub fn validator_rewarded( validator_id: u64, from: Address, amount: U256, epoch: u64, ) -> Self
Creates a ValidatorRewarded event.
event ValidatorRewarded(uint64,address,uint256,uint64)Sourcepub fn validator_created(
validator_id: u64,
auth_address: Address,
commission: U256,
) -> Self
pub fn validator_created( validator_id: u64, auth_address: Address, commission: U256, ) -> Self
Creates a ValidatorCreated event.
event ValidatorCreated(uint64,address,uint256)Sourcepub fn validator_status_changed(validator_id: u64, flags: u64) -> Self
pub fn validator_status_changed(validator_id: u64, flags: u64) -> Self
Creates a ValidatorStatusChanged event.
event ValidatorStatusChanged(uint64,uint64)Sourcepub fn delegate(
validator_id: u64,
delegator: Address,
amount: U256,
activation_epoch: u64,
) -> Self
pub fn delegate( validator_id: u64, delegator: Address, amount: U256, activation_epoch: u64, ) -> Self
Creates a Delegate event.
event Delegate(uint64,address,uint256,uint64)Sourcepub fn undelegate(
validator_id: u64,
delegator: Address,
withdraw_id: u8,
amount: U256,
activation_epoch: u64,
) -> Self
pub fn undelegate( validator_id: u64, delegator: Address, withdraw_id: u8, amount: U256, activation_epoch: u64, ) -> Self
Creates a Undelegate event.
event Undelegate(uint64,address,uint8,uint256,uint64)Sourcepub fn withdraw(
validator_id: u64,
delegator: Address,
withdraw_id: u8,
amount: U256,
epoch: u64,
) -> Self
pub fn withdraw( validator_id: u64, delegator: Address, withdraw_id: u8, amount: U256, epoch: u64, ) -> Self
Creates a Withdraw event.
event Withdraw(uint64,address,uint8,uint256,uint64)Sourcepub fn claim_rewards(
validator_id: u64,
delegator: Address,
amount: U256,
epoch: u64,
) -> Self
pub fn claim_rewards( validator_id: u64, delegator: Address, amount: U256, epoch: u64, ) -> Self
Creates a ClaimRewards event.
event ClaimRewards(uint64,address,uint256,uint64)Sourcepub fn commission_changed(
validator_id: u64,
old_commission: U256,
new_commission: U256,
) -> Self
pub fn commission_changed( validator_id: u64, old_commission: U256, new_commission: U256, ) -> Self
Creates a CommissionChanged event.
event CommissionChanged(uint64,uint256,uint256)Sourcepub fn epoch_changed(old_epoch: u64, new_epoch: u64) -> Self
pub fn epoch_changed(old_epoch: u64, new_epoch: u64) -> Self
Creates a EpochChanged event.
event EpochChanged(uint64,uint64)Trait Implementations
Sourceimpl Clone for IMonadStakingEvents
impl Clone for IMonadStakingEvents
Sourcefn clone(&self) -> IMonadStakingEvents
fn clone(&self) -> IMonadStakingEvents
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl IntoLogData for IMonadStakingEvents
impl IntoLogData for IMonadStakingEvents
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
LogData] object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
LogData] object.Sourceimpl SolEventInterface for IMonadStakingEvents
impl SolEventInterface for IMonadStakingEvents
Sourcefn decode_raw_log(topics: &[Word], data: &[u8]) -> Result<Self>
fn decode_raw_log(topics: &[Word], data: &[u8]) -> Result<Self>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>